;------------------------------------------------------------------------------
; Description:  Read the content of a state shapefile and write the latitude 
;               and longitude value pairs of the selected state into a CSV 
;               file (e.g. to use it with CDO's maskregion operator).
;
; Output file:    Selected state name + '_lonlat.csv'
;
; Output format: Float values for latitude and longitude as CSV with 
;               delimiter ' '.
;
;                   -110.82376099 31.33125305
;                   -110.82608032 31.33123779
;                   ...
;
; Shapefile:    Download from https://gadm.org/
;
; Later use:    cdo -maskregion,Arizona_lonlat.csv infile outfile
;
; 08.07.20  meier-fleischer
;------------------------------------------------------------------------------  

select_state = "Bamako" 
outfile      = select_state+"_lonlat.csv" 

shpf = addfile("/home/amadou/Desktop/Works/modi/sheefiles/Bamako/Bamako.shp","r")

shp_states    = shpf->NAME_1                ;-- US state names [num_features]
segments      = shpf->segments              ;-- shapefile segments [num_segments, segments]
geometry      = shpf->geometry              ;-- shapefile geometry [num_features, geometry]
lon           = shpf->x                     ;-- longitude values [num_points]
lat           = shpf->y                     ;-- latitude values  [num_points]

geom_segIndex = shpf@geom_segIndex          ;-- geometry start index number
segs_xyzIndex = shpf@segs_xyzIndex          ;-- segments start index number
segs_numPnts  = shpf@segs_numPnts           ;-- segments number of points or sets

print("")
print("Selected state:  "+select_state)
print("Output file:     "+outfile)
print("")

do i = 0, dimsizes(select_state)-1
   do j = 0, dimsizes(shp_states)-1
      if (shp_states(j) .eq. select_state(i)) then 
         start_segment = geometry(j, geom_segIndex)
         start_point   = segments(start_segment, segs_xyzIndex)
         end_point     = start_point + segments(start_segment,segs_numPnts) -1

         state_lat = lat(start_point:end_point) ;-- lat values of selected state
         state_lon = lon(start_point:end_point) ;-- lon values of selected state
         print("Number of points for "+select_state+": "+dimsizes(state_lon))
         print("")
      end if
   end do   
end do

; https://code.mpimet.mpg.de/boards/53/topics/9689
; https://www.guillaumedueymes.com/post/shapefiles_country/


